<?php
/**
 * Copyright © 2015 FiloBlu . All rights reserved.
 */
namespace FiloBlu\Flow\Helper;

/**
 * Class Images
 * @package FiloBlu\Flow\Helper
 */
class Images extends \Magento\Framework\App\Helper\AbstractHelper
{
    /**
     * @var
     */
    protected $_objectManager;
    /**
     * @var \Magento\Framework\App\ResourceConnection
     */
    protected $connection;

    public function __construct(
        \Magento\Framework\App\Helper\Context $context,
        \Magento\Framework\App\ResourceConnection $connection
    ) {
        $this->connection=$connection;
        parent::__construct($context);
    }

    /**
     * @return mixed
     */
    public function isFullPhotoCleanActive(){
        $flag = $this->scopeConfig->getValue('filoblu_flow/flow_images/flow_images_force_clean', \Magento\Store\Model\ScopeInterface::SCOPE_WEBSITE);
        return $flag;
    }

    /**
     * @return mixed
     */
    public function isClearImageCacheActive(){
        $flag = $this->scopeConfig->getValue('filoblu_flow/flow_images/flow_images_clean_cache', \Magento\Store\Model\ScopeInterface::SCOPE_WEBSITE);
        return $flag;
    }

    /**
     * @return mixed
     */
    public function isUniqueUploadImagesActive(){
        $flag = $this->scopeConfig->getValue('filoblu_flow/flow_images/flow_images_upload_unique', \Magento\Store\Model\ScopeInterface::SCOPE_WEBSITE);
        return $flag;
    }

    /**
     * Returns an array of folders of $source_dir
     */
    public function foldersMap($source_dir, $directory_depth = 0, $hidden = FALSE)
    {
        if ($fp = @opendir($source_dir))
        {
            $filedata   = array();
            $new_depth  = $directory_depth - 1;
            $source_dir = rtrim($source_dir, '/').'/';

            while (FALSE !== ($file = readdir($fp)))
            {
                // Remove '.', '..', and hidden files [optional]
                if ( ! trim($file, '.') OR ($hidden == FALSE && $file[0] == '.'))
                {
                    continue;
                }

                if (($directory_depth < 1 OR $new_depth > 0) && @is_dir($source_dir.$file))
                {
                    $filedata[$file] = $this->foldersMap($source_dir.$file.'/', $new_depth, $hidden);
                }
                else
                {
                    $filedata[] = $file;
                }
            }

            closedir($fp);
            return $filedata;
        }
        echo 'can not open dir';
        return FALSE;
    }

    /**
     * This function will get as input one array of folders from foldersMap function
     * Then will convert that array into paths (strings) of the magento
     * images cache folder checking that the last folder is an MD5 (because this is how Magento builds the image caches paths)
     * https://www.sonassi.com/blog/knowledge-base/deconstructing-the-cache-image-path-on-magento
     *
     * $result = array();
     * collapse("",$array_of_paths,$result);
     *
     * $result will be an array of paths (strings)
     */
    public function collapse($path, $collapse, &$result)
    {
        foreach($collapse AS $key => $value)
        {
            if(is_array($value))
            {
                $this->collapse($path . $key . DIRECTORY_SEPARATOR, $value, $result);
                continue;
            }

            if(preg_match('/^[a-f0-9]{32}$/', $value)){
                $result[] = $path . $value . DIRECTORY_SEPARATOR;
            } else {
                $result[] = $path;
            }

        }
    }

}


